Analysis Modules
================

.. automodule:: ferro_ta.analysis.options
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: ferro_ta.analysis.futures
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: ferro_ta.analysis.options_strategy
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: ferro_ta.analysis.derivatives_payoff
   :members:
   :undoc-members:
   :show-inheritance:
